@@ -47,6 +47,16 @@ class IoTNodeConfig(object):
             self._config.add_section(section)
             self._write_config()
 
+    def _parse_color(self, value, on_error='auto'):
+        color = value.split(':')
+        if len(color) not in (3, 4):
+            return on_error
+        try:
+            color = (float(x) for x in color)
+        except ValueError:
+            return on_error
+        return tuple(color)
+
     # Paths
     @property
     def app_root(self):
@@ -149,6 +159,10 @@ class IoTNodeConfig(object):
     def foundation_image(self):
         return self._config.get('display-rpi', 'foundation_image', fallback=None)
 
+    @property
+    def image_bgcolor(self):
+        return self._parse_color(self._config.get('display', 'image_bgcolor', fallback='auto'))
+
     @property
     def background(self):
         return self._config.get('display', 'background', fallback='images/background.png')
